local _, ns = ...
local OnCast = ns.addon
local module = OnCast:NewModule("ExtInfo")

-- Extended channel name
local CHANNEL = "INFO"

-- Lua APIs

-- Modules
local Util = nil

-- Module functions
function module:OnInitialize()
    Util = OnCast:GetModule("Util")
end

function module:OnEnable()
    OnCast.AddExtendedChannel(CHANNEL, module)
end

function module:OnDisable()
    OnCast.RemoveExtendedChannel(CHANNEL)
end

function module.Help()
    OnCast.printInfoMessage("-- INFO --", OnCast.HEADING_COLOR)
    OnCast.printInfoMessage("Usage: info(Color)")
    OnCast.printInfoMessage("Color: RRGGBB in Hexidecimal; e.g. FFC4A9")
end

-- Check if a var is not blank; i.e. _ (underscore)
local function notBlank(value)
    return (value and value ~= "_")
end

function module.VarsToTable(vars, n)
    -- Early exit for common use case
    if n <= 0 then return true, nil end

    -- Color
    local color = vars[1]
    if notBlank(color) then
        if #color ~= 6 then
            OnCast.printErrorMessage("Invalid color. Expected format: RRGGBB")
            return false, nil
        end
        local n = Util.colorStringToTable(color)
        if n ~= 3 then
            OnCast.printErrorMessage("Invalid color. Expected Hexidecimal digits [0-9,A-F]")
            return false, nil
        end
        vars.color = color
    end
    vars[1] = nil

    -- Clear any other values
    for i=2, n do vars[i] = nil end

    return true, vars
end

function module.VarsToArray(vars)
    local array = {}
    array[1] = vars.color or "_"
    return array
end

function module.ShowMessage(message, vars, cast)
    OnCast.printInfoMessage(message, vars and vars.color or "b0c4de")
end
